.. _next-steps:

Next steps
~~~~~~~~~~

Your OpenStack environment now includes the Murano service.

Import Murano Applications
--------------------------
.. include:: import-murano-apps.rst

Additional Resources
--------------------

#. To add additional services, see
   `<https://docs.openstack.org/latest/install/>`__.

#. If you would like to add glare as the storage service for packages, see:
   `<https://docs.openstack.org/murano/latest/admin/using_glare.html>`__.
